<?php

class Cornerstone_Modal extends Cornerstone_Element_Base {

	public function data() {
		return array(
			'name'        => 'cornerstone-modal',
			'title'       => __( 'Modal', 'xtt' ),
			'section'     => 'content',
			'description' => __( 'Adds a modal box to your content.', 'xtt' ),
			'supports'    => array( 'id', 'class', 'style' ),
		);
	}

	public function controls() {

		$this->addControl(
			'modalcontent',
			'editor',
			__( 'Modal Content', 'xtt' ),
			__( 'Content that will display in modal popup.', 'xtt' ),
			''
		);

		$this->addControl(
			'display_on',
			'select',
			__( 'Display Modal On', 'xtt' ),
			__( 'When should the popup be initiated.', 'xtt' ),
			'button',
			array(
				'choices' => array(
					array( 'value' => 'button',  'label' => __( 'Button', 'xtt' ) ),
					array( 'value' => 'element', 'label' => __( 'Element Click', 'xtt' ) ),
					array( 'value' => 'load', 'label' => __( 'Page Load', 'xtt' ) )
				)
			)
		);

		// Element

		$this->addControl(
			'identifier',
			'text',
			__( 'Element Identifier', 'xtt' ),
			__( 'Enter the CSS class or ID of the page element that will trigger the modal.', 'xtt' ),
			'',
			array(
				'condition' => array(
					'display_on' => 'element'
				)
			)
		);

		// Button

		$this->addControl(
			'button_size',
			'select',
			__( 'Button Size', 'xtt' ),
			__( 'How big of a button would you like?', 'xtt' ),
			'default',
			array(
				'choices' => array(
					array( 'value' => 'default',  'label' => __( 'Theme Default', 'xtt' ) ),
					array( 'value' => 'x-btn-small', 'label' => __( 'Small', 'xtt' ) ),
					array( 'value' => 'x-btn-medium', 'label' => __( 'Medium', 'xtt' ) ),
					array( 'value' => 'x-btn-large', 'label' => __( 'Large', 'xtt' ) ),
				),
				'condition' => array(
					'display_on' => 'button'
				)
			)
		);

		$this->addControl(
			'button_text',
			'text',
			__( 'Button Text', 'xtt' ),
			__( 'Provide a title for this button.', 'xtt' ),
			'Click Me',
			array(
				'condition' => array(
					'display_on' => 'button'
				)
			)
		);

		// Page load

	    $this->addControl(
	      'delay',
	      'number',
	      __( 'Delay', 'xtt' ),
	      __( 'Time delay before modal popup on page load (in seconds).', 'xtt' ),
	      '2',
			array(
				'condition' => array(
					'display_on' => 'load'
				)
			)
	    );

	}

	public function render( $atts ) {

		extract( $atts );

		$shortcode = "[cornerstone_modal display_on='{$display_on}' btn_size='{$button_size}' btn_txt='{$button_text}' identifier='{$identifier}' delay='{$delay}' {$extra}]{$modalcontent}[/cornerstone_modal]";

		return $shortcode;

	}

}